# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/mdb/kafka/v1/topic_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2
from yandex.cloud.mdb.kafka.v1 import topic_pb2 as yandex_dot_cloud_dot_mdb_dot_kafka_dot_v1_dot_topic__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yandex/cloud/mdb/kafka/v1/topic_service.proto',
  package='yandex.cloud.mdb.kafka.v1',
  syntax='proto3',
  serialized_options=b'\n\035yandex.cloud.api.mdb.kafka.v1ZCgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/kafka/v1;kafka',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n-yandex/cloud/mdb/kafka/v1/topic_service.proto\x12\x19yandex.cloud.mdb.kafka.v1\x1a\x1cgoogle/api/annotations.proto\x1a google/protobuf/field_mask.proto\x1a yandex/cloud/api/operation.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x1dyandex/cloud/validation.proto\x1a%yandex/cloud/mdb/kafka/v1/topic.proto\"g\n\x0fGetTopicRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x32\n\ntopic_name\x18\x02 \x01(\tB\x1e\xe8\xc7\x31\x01\x8a\xc8\x31\x04\x31-63\xf2\xc7\x31\x0e[a-zA-Z0-9_-]*\"s\n\x11ListTopicsRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06<=1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\"_\n\x12ListTopicsResponse\x12\x30\n\x06topics\x18\x01 \x03(\x0b\x32 .yandex.cloud.mdb.kafka.v1.Topic\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"v\n\x12\x43reateTopicRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12>\n\ntopic_spec\x18\x02 \x01(\x0b\x32$.yandex.cloud.mdb.kafka.v1.TopicSpecB\x04\xe8\xc7\x31\x01\"]\n\x13\x43reateTopicMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\x12\x32\n\ntopic_name\x18\x02 \x01(\tB\x1e\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=63\xf2\xc7\x31\x0e[a-zA-Z0-9_-]*\"\xd5\x01\n\x12UpdateTopicRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x32\n\ntopic_name\x18\x02 \x01(\tB\x1e\xe8\xc7\x31\x01\x8a\xc8\x31\x04\x31-63\xf2\xc7\x31\x0e[a-zA-Z0-9_-]*\x12/\n\x0bupdate_mask\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12\x38\n\ntopic_spec\x18\x04 \x01(\x0b\x32$.yandex.cloud.mdb.kafka.v1.TopicSpec\"=\n\x13UpdateTopicMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\x12\x12\n\ntopic_name\x18\x02 \x01(\t\"j\n\x12\x44\x65leteTopicRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x32\n\ntopic_name\x18\x02 \x01(\tB\x1e\xe8\xc7\x31\x01\x8a\xc8\x31\x04\x31-63\xf2\xc7\x31\x0e[a-zA-Z0-9_-]*\"=\n\x13\x44\x65leteTopicMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\x12\x12\n\ntopic_name\x18\x02 \x01(\t2\x96\x07\n\x0cTopicService\x12\x98\x01\n\x03Get\x12*.yandex.cloud.mdb.kafka.v1.GetTopicRequest\x1a .yandex.cloud.mdb.kafka.v1.Topic\"C\x82\xd3\xe4\x93\x02=\x12;/managed-kafka/v1/clusters/{cluster_id}/topics/{topic_name}\x12\x9b\x01\n\x04List\x12,.yandex.cloud.mdb.kafka.v1.ListTopicsRequest\x1a-.yandex.cloud.mdb.kafka.v1.ListTopicsResponse\"6\x82\xd3\xe4\x93\x02\x30\x12./managed-kafka/v1/clusters/{cluster_id}/topics\x12\xb5\x01\n\x06\x43reate\x12-.yandex.cloud.mdb.kafka.v1.CreateTopicRequest\x1a!.yandex.cloud.operation.Operation\"Y\x82\xd3\xe4\x93\x02\x33\"./managed-kafka/v1/clusters/{cluster_id}/topics:\x01*\xb2\xd2*\x1c\n\x13\x43reateTopicMetadata\x12\x05Topic\x12\xc2\x01\n\x06Update\x12-.yandex.cloud.mdb.kafka.v1.UpdateTopicRequest\x1a!.yandex.cloud.operation.Operation\"f\x82\xd3\xe4\x93\x02@2;/managed-kafka/v1/clusters/{cluster_id}/topics/{topic_name}:\x01*\xb2\xd2*\x1c\n\x13UpdateTopicMetadata\x12\x05Topic\x12\xcf\x01\n\x06\x44\x65lete\x12-.yandex.cloud.mdb.kafka.v1.DeleteTopicRequest\x1a!.yandex.cloud.operation.Operation\"s\x82\xd3\xe4\x93\x02=*;/managed-kafka/v1/clusters/{cluster_id}/topics/{topic_name}\xb2\xd2*,\n\x13\x44\x65leteTopicMetadata\x12\x15google.protobuf.EmptyBd\n\x1dyandex.cloud.api.mdb.kafka.v1ZCgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/kafka/v1;kafkab\x06proto3'
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,google_dot_protobuf_dot_field__mask__pb2.DESCRIPTOR,yandex_dot_cloud_dot_api_dot_operation__pb2.DESCRIPTOR,yandex_dot_cloud_dot_operation_dot_operation__pb2.DESCRIPTOR,yandex_dot_cloud_dot_validation__pb2.DESCRIPTOR,yandex_dot_cloud_dot_mdb_dot_kafka_dot_v1_dot_topic__pb2.DESCRIPTOR,])




_GETTOPICREQUEST = _descriptor.Descriptor(
  name='GetTopicRequest',
  full_name='yandex.cloud.mdb.kafka.v1.GetTopicRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cluster_id', full_name='yandex.cloud.mdb.kafka.v1.GetTopicRequest.cluster_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='topic_name', full_name='yandex.cloud.mdb.kafka.v1.GetTopicRequest.topic_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\0041-63\362\3071\016[a-zA-Z0-9_-]*', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=284,
  serialized_end=387,
)


_LISTTOPICSREQUEST = _descriptor.Descriptor(
  name='ListTopicsRequest',
  full_name='yandex.cloud.mdb.kafka.v1.ListTopicsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cluster_id', full_name='yandex.cloud.mdb.kafka.v1.ListTopicsRequest.cluster_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_size', full_name='yandex.cloud.mdb.kafka.v1.ListTopicsRequest.page_size', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\006<=1000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_token', full_name='yandex.cloud.mdb.kafka.v1.ListTopicsRequest.page_token', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\005<=100', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=389,
  serialized_end=504,
)


_LISTTOPICSRESPONSE = _descriptor.Descriptor(
  name='ListTopicsResponse',
  full_name='yandex.cloud.mdb.kafka.v1.ListTopicsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='topics', full_name='yandex.cloud.mdb.kafka.v1.ListTopicsResponse.topics', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='yandex.cloud.mdb.kafka.v1.ListTopicsResponse.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=506,
  serialized_end=601,
)


_CREATETOPICREQUEST = _descriptor.Descriptor(
  name='CreateTopicRequest',
  full_name='yandex.cloud.mdb.kafka.v1.CreateTopicRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cluster_id', full_name='yandex.cloud.mdb.kafka.v1.CreateTopicRequest.cluster_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='topic_spec', full_name='yandex.cloud.mdb.kafka.v1.CreateTopicRequest.topic_spec', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=603,
  serialized_end=721,
)


_CREATETOPICMETADATA = _descriptor.Descriptor(
  name='CreateTopicMetadata',
  full_name='yandex.cloud.mdb.kafka.v1.CreateTopicMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cluster_id', full_name='yandex.cloud.mdb.kafka.v1.CreateTopicMetadata.cluster_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='topic_name', full_name='yandex.cloud.mdb.kafka.v1.CreateTopicMetadata.topic_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=63\362\3071\016[a-zA-Z0-9_-]*', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=723,
  serialized_end=816,
)


_UPDATETOPICREQUEST = _descriptor.Descriptor(
  name='UpdateTopicRequest',
  full_name='yandex.cloud.mdb.kafka.v1.UpdateTopicRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cluster_id', full_name='yandex.cloud.mdb.kafka.v1.UpdateTopicRequest.cluster_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='topic_name', full_name='yandex.cloud.mdb.kafka.v1.UpdateTopicRequest.topic_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\0041-63\362\3071\016[a-zA-Z0-9_-]*', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='update_mask', full_name='yandex.cloud.mdb.kafka.v1.UpdateTopicRequest.update_mask', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='topic_spec', full_name='yandex.cloud.mdb.kafka.v1.UpdateTopicRequest.topic_spec', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=819,
  serialized_end=1032,
)


_UPDATETOPICMETADATA = _descriptor.Descriptor(
  name='UpdateTopicMetadata',
  full_name='yandex.cloud.mdb.kafka.v1.UpdateTopicMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cluster_id', full_name='yandex.cloud.mdb.kafka.v1.UpdateTopicMetadata.cluster_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='topic_name', full_name='yandex.cloud.mdb.kafka.v1.UpdateTopicMetadata.topic_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1034,
  serialized_end=1095,
)


_DELETETOPICREQUEST = _descriptor.Descriptor(
  name='DeleteTopicRequest',
  full_name='yandex.cloud.mdb.kafka.v1.DeleteTopicRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cluster_id', full_name='yandex.cloud.mdb.kafka.v1.DeleteTopicRequest.cluster_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='topic_name', full_name='yandex.cloud.mdb.kafka.v1.DeleteTopicRequest.topic_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\0041-63\362\3071\016[a-zA-Z0-9_-]*', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1097,
  serialized_end=1203,
)


_DELETETOPICMETADATA = _descriptor.Descriptor(
  name='DeleteTopicMetadata',
  full_name='yandex.cloud.mdb.kafka.v1.DeleteTopicMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cluster_id', full_name='yandex.cloud.mdb.kafka.v1.DeleteTopicMetadata.cluster_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='topic_name', full_name='yandex.cloud.mdb.kafka.v1.DeleteTopicMetadata.topic_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1205,
  serialized_end=1266,
)

_LISTTOPICSRESPONSE.fields_by_name['topics'].message_type = yandex_dot_cloud_dot_mdb_dot_kafka_dot_v1_dot_topic__pb2._TOPIC
_CREATETOPICREQUEST.fields_by_name['topic_spec'].message_type = yandex_dot_cloud_dot_mdb_dot_kafka_dot_v1_dot_topic__pb2._TOPICSPEC
_UPDATETOPICREQUEST.fields_by_name['update_mask'].message_type = google_dot_protobuf_dot_field__mask__pb2._FIELDMASK
_UPDATETOPICREQUEST.fields_by_name['topic_spec'].message_type = yandex_dot_cloud_dot_mdb_dot_kafka_dot_v1_dot_topic__pb2._TOPICSPEC
DESCRIPTOR.message_types_by_name['GetTopicRequest'] = _GETTOPICREQUEST
DESCRIPTOR.message_types_by_name['ListTopicsRequest'] = _LISTTOPICSREQUEST
DESCRIPTOR.message_types_by_name['ListTopicsResponse'] = _LISTTOPICSRESPONSE
DESCRIPTOR.message_types_by_name['CreateTopicRequest'] = _CREATETOPICREQUEST
DESCRIPTOR.message_types_by_name['CreateTopicMetadata'] = _CREATETOPICMETADATA
DESCRIPTOR.message_types_by_name['UpdateTopicRequest'] = _UPDATETOPICREQUEST
DESCRIPTOR.message_types_by_name['UpdateTopicMetadata'] = _UPDATETOPICMETADATA
DESCRIPTOR.message_types_by_name['DeleteTopicRequest'] = _DELETETOPICREQUEST
DESCRIPTOR.message_types_by_name['DeleteTopicMetadata'] = _DELETETOPICMETADATA
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GetTopicRequest = _reflection.GeneratedProtocolMessageType('GetTopicRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETTOPICREQUEST,
  '__module__' : 'yandex.cloud.mdb.kafka.v1.topic_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.kafka.v1.GetTopicRequest)
  })
_sym_db.RegisterMessage(GetTopicRequest)

ListTopicsRequest = _reflection.GeneratedProtocolMessageType('ListTopicsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTTOPICSREQUEST,
  '__module__' : 'yandex.cloud.mdb.kafka.v1.topic_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.kafka.v1.ListTopicsRequest)
  })
_sym_db.RegisterMessage(ListTopicsRequest)

ListTopicsResponse = _reflection.GeneratedProtocolMessageType('ListTopicsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTTOPICSRESPONSE,
  '__module__' : 'yandex.cloud.mdb.kafka.v1.topic_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.kafka.v1.ListTopicsResponse)
  })
_sym_db.RegisterMessage(ListTopicsResponse)

CreateTopicRequest = _reflection.GeneratedProtocolMessageType('CreateTopicRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATETOPICREQUEST,
  '__module__' : 'yandex.cloud.mdb.kafka.v1.topic_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.kafka.v1.CreateTopicRequest)
  })
_sym_db.RegisterMessage(CreateTopicRequest)

CreateTopicMetadata = _reflection.GeneratedProtocolMessageType('CreateTopicMetadata', (_message.Message,), {
  'DESCRIPTOR' : _CREATETOPICMETADATA,
  '__module__' : 'yandex.cloud.mdb.kafka.v1.topic_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.kafka.v1.CreateTopicMetadata)
  })
_sym_db.RegisterMessage(CreateTopicMetadata)

UpdateTopicRequest = _reflection.GeneratedProtocolMessageType('UpdateTopicRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATETOPICREQUEST,
  '__module__' : 'yandex.cloud.mdb.kafka.v1.topic_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.kafka.v1.UpdateTopicRequest)
  })
_sym_db.RegisterMessage(UpdateTopicRequest)

UpdateTopicMetadata = _reflection.GeneratedProtocolMessageType('UpdateTopicMetadata', (_message.Message,), {
  'DESCRIPTOR' : _UPDATETOPICMETADATA,
  '__module__' : 'yandex.cloud.mdb.kafka.v1.topic_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.kafka.v1.UpdateTopicMetadata)
  })
_sym_db.RegisterMessage(UpdateTopicMetadata)

DeleteTopicRequest = _reflection.GeneratedProtocolMessageType('DeleteTopicRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETETOPICREQUEST,
  '__module__' : 'yandex.cloud.mdb.kafka.v1.topic_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.kafka.v1.DeleteTopicRequest)
  })
_sym_db.RegisterMessage(DeleteTopicRequest)

DeleteTopicMetadata = _reflection.GeneratedProtocolMessageType('DeleteTopicMetadata', (_message.Message,), {
  'DESCRIPTOR' : _DELETETOPICMETADATA,
  '__module__' : 'yandex.cloud.mdb.kafka.v1.topic_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.kafka.v1.DeleteTopicMetadata)
  })
_sym_db.RegisterMessage(DeleteTopicMetadata)


DESCRIPTOR._options = None
_GETTOPICREQUEST.fields_by_name['cluster_id']._options = None
_GETTOPICREQUEST.fields_by_name['topic_name']._options = None
_LISTTOPICSREQUEST.fields_by_name['cluster_id']._options = None
_LISTTOPICSREQUEST.fields_by_name['page_size']._options = None
_LISTTOPICSREQUEST.fields_by_name['page_token']._options = None
_CREATETOPICREQUEST.fields_by_name['cluster_id']._options = None
_CREATETOPICREQUEST.fields_by_name['topic_spec']._options = None
_CREATETOPICMETADATA.fields_by_name['topic_name']._options = None
_UPDATETOPICREQUEST.fields_by_name['cluster_id']._options = None
_UPDATETOPICREQUEST.fields_by_name['topic_name']._options = None
_DELETETOPICREQUEST.fields_by_name['cluster_id']._options = None
_DELETETOPICREQUEST.fields_by_name['topic_name']._options = None

_TOPICSERVICE = _descriptor.ServiceDescriptor(
  name='TopicService',
  full_name='yandex.cloud.mdb.kafka.v1.TopicService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=1269,
  serialized_end=2187,
  methods=[
  _descriptor.MethodDescriptor(
    name='Get',
    full_name='yandex.cloud.mdb.kafka.v1.TopicService.Get',
    index=0,
    containing_service=None,
    input_type=_GETTOPICREQUEST,
    output_type=yandex_dot_cloud_dot_mdb_dot_kafka_dot_v1_dot_topic__pb2._TOPIC,
    serialized_options=b'\202\323\344\223\002=\022;/managed-kafka/v1/clusters/{cluster_id}/topics/{topic_name}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='List',
    full_name='yandex.cloud.mdb.kafka.v1.TopicService.List',
    index=1,
    containing_service=None,
    input_type=_LISTTOPICSREQUEST,
    output_type=_LISTTOPICSRESPONSE,
    serialized_options=b'\202\323\344\223\0020\022./managed-kafka/v1/clusters/{cluster_id}/topics',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Create',
    full_name='yandex.cloud.mdb.kafka.v1.TopicService.Create',
    index=2,
    containing_service=None,
    input_type=_CREATETOPICREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\0023\"./managed-kafka/v1/clusters/{cluster_id}/topics:\001*\262\322*\034\n\023CreateTopicMetadata\022\005Topic',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Update',
    full_name='yandex.cloud.mdb.kafka.v1.TopicService.Update',
    index=3,
    containing_service=None,
    input_type=_UPDATETOPICREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002@2;/managed-kafka/v1/clusters/{cluster_id}/topics/{topic_name}:\001*\262\322*\034\n\023UpdateTopicMetadata\022\005Topic',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Delete',
    full_name='yandex.cloud.mdb.kafka.v1.TopicService.Delete',
    index=4,
    containing_service=None,
    input_type=_DELETETOPICREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002=*;/managed-kafka/v1/clusters/{cluster_id}/topics/{topic_name}\262\322*,\n\023DeleteTopicMetadata\022\025google.protobuf.Empty',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_TOPICSERVICE)

DESCRIPTOR.services_by_name['TopicService'] = _TOPICSERVICE

# @@protoc_insertion_point(module_scope)



"""Main package for Yandex.Cloud SDK."""

from yandexcloud._sdk import SDK
from yandexcloud._retry_interceptor import RetryInterceptor
from yandexcloud._backoff import backoff_linear_with_jitter, backoff_exponential_with_jitter, default_backoff


__version__ = '0.0.2'



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/ai/vision/v1/primitives.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='yandex/cloud/ai/vision/v1/primitives.proto',
  package='yandex.cloud.ai.vision.v1',
  syntax='proto3',
  serialized_options=b'\n\035yandex.cloud.api.ai.vision.v1ZDgithub.com/yandex-cloud/go-genproto/yandex/cloud/ai/vision/v1;vision',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n*yandex/cloud/ai/vision/v1/primitives.proto\x12\x19yandex.cloud.ai.vision.v1\">\n\x07Polygon\x12\x33\n\x08vertices\x18\x01 \x03(\x0b\x32!.yandex.cloud.ai.vision.v1.Vertex\"\x1e\n\x06Vertex\x12\t\n\x01x\x18\x01 \x01(\x03\x12\t\n\x01y\x18\x02 \x01(\x03\x42\x65\n\x1dyandex.cloud.api.ai.vision.v1ZDgithub.com/yandex-cloud/go-genproto/yandex/cloud/ai/vision/v1;visionb\x06proto3'
)




_POLYGON = _descriptor.Descriptor(
  name='Polygon',
  full_name='yandex.cloud.ai.vision.v1.Polygon',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='vertices', full_name='yandex.cloud.ai.vision.v1.Polygon.vertices', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=73,
  serialized_end=135,
)


_VERTEX = _descriptor.Descriptor(
  name='Vertex',
  full_name='yandex.cloud.ai.vision.v1.Vertex',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='x', full_name='yandex.cloud.ai.vision.v1.Vertex.x', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='y', full_name='yandex.cloud.ai.vision.v1.Vertex.y', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=137,
  serialized_end=167,
)

_POLYGON.fields_by_name['vertices'].message_type = _VERTEX
DESCRIPTOR.message_types_by_name['Polygon'] = _POLYGON
DESCRIPTOR.message_types_by_name['Vertex'] = _VERTEX
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Polygon = _reflection.GeneratedProtocolMessageType('Polygon', (_message.Message,), {
  'DESCRIPTOR' : _POLYGON,
  '__module__' : 'yandex.cloud.ai.vision.v1.primitives_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.ai.vision.v1.Polygon)
  })
_sym_db.RegisterMessage(Polygon)

Vertex = _reflection.GeneratedProtocolMessageType('Vertex', (_message.Message,), {
  'DESCRIPTOR' : _VERTEX,
  '__module__' : 'yandex.cloud.ai.vision.v1.primitives_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.ai.vision.v1.Vertex)
  })
_sym_db.RegisterMessage(Vertex)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
